@@ -15,8 +15,13 @@ def download_file(url: str, out_path: str):
     from sdkit.utils import log
 
     start_offset = 0 if not os.path.exists(out_path) else os.path.getsize(out_path)
-    res = requests.get(url, stream=True, headers={'Range': f'bytes={start_offset}-', 'Accept-Encoding': 'identity'})
+    res = requests.get(url, stream=True)
+    if not res.ok: return
     total_bytes = int(res.headers.get('Content-Length', '0'))
+
+    res = requests.get(url, stream=True, headers={'Range': f'bytes={start_offset}-', 'Accept-Encoding': 'identity'})
+    if not res.ok: return
+
     write_mode = 'wb' if start_offset == 0 else 'ab'
 
     log.info(f'Downloading {url} to {out_path}')
